@@ -8,7 +8,9 @@ import markdown
 from psiutils.constants import PAD, Pad
 from psiutils.utilities import window_resize
 
-from psiutils import text as txt
+from psiutils.text import Text
+
+txt = Text()
 
 DEFAULT_GEOMETRY = '400x200'
 HISTORY_GEOMETRY = '800x750'
