@@ -4,6 +4,7 @@ from copy import copy
 
 
 psi_strings = {
+    'BACKUP': 'Backup',
     'BUILD': 'Build',
     'CANCEL': 'Cancel',
     'CHECK': 'Check',
@@ -38,6 +39,7 @@ psi_strings = {
     'REPORT': 'Report',
     'RENAME': 'Rename',
     'RESET': 'Reset',
+    'RESTORE': 'Restore',
     'REVERT': 'Revert',
     'RUN': 'Run',
     'SAVE': 'Save',
@@ -60,7 +62,7 @@ class Text():
     """Combines package level and psiutils strings."""
     def __init__(self) -> None:
         """
-        Initialize the object with attributes based on the key-value pairs
+        Initialise the object with attributes based on the key-value pairs
         in the `strings` dictionary.
 
         Args:
