@@ -1,4 +1,5 @@
 """Common methods for psiutils."""
+import sys
 from pathlib import Path
 import tkinter as tk
 import ctypes
@@ -6,13 +7,12 @@ from typing import Any
 import platform
 
 from psiconfig import TomlConfig
-import psiutils.text as txt
-
-# Exposes psi_logger to other applications
 from psiutils._logger import psi_logger
 from psiutils._notify import _notify as notify
+from psiutils.constants import DEFAULT_GEOMETRY
+from psiutils.text import Text
 
-DEFAULT_GEOMETRY = '500x400'
+txt = Text()
 
 
 def display_icon(root: tk.Tk, icon_file_path: str,
@@ -28,6 +28,16 @@ def display_icon(root: tk.Tk, icon_file_path: str,
         print(f'Cannot find icon file: {icon_file_path}')
 
 
+def resource_path(base: Path, relative_path: Path):
+    """ Get absolute path to resource, works for dev and for PyInstaller."""
+    try:
+        # PyInstaller creates a temp folder and stores path in _MEIPASS
+        base_path = sys._MEIPASS
+    except Exception:
+        base_path = Path(base).parent
+    return Path(base_path, relative_path)
+
+
 class Enum():
     def __init__(self, values: dict) -> None:
         self.values = invert(values)
@@ -75,6 +85,7 @@ def enable_frame(parent: tk.Frame, enable: bool = True) -> None:
         else:
             child.configure(state=state)
 
+
 def geometry(config: TomlConfig, file: Path, default: str = '') -> str:
     if not default:
         default = DEFAULT_GEOMETRY
